@@ -1,3 +1,3 @@
 from theblockchainapi.resource import TheBlockchainAPIResource, \
     SolanaNetwork, SolanaCurrencyUnit, SolanaNFTUploadMethod, SolanaMintAddresses, SolanaCandyMachineContractVersion, \
-    SearchMethod, SolanaWallet, DerivationPath
+    SearchMethod, SolanaWallet, DerivationPath, SolanaExchange
